==> 1.0.2.tar.gz: example/example_backdrop/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:backdrop_material_widget/backdrop_material_widget.dart';
import 'package:example_backdrop/one_page_screen.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final GlobalKey<BackdropScaffoldState> _key = GlobalKey();
    final destinations = [
      NavigationDestination(
          icon: Icon(Icons.title),
          title: Text('Test'),
          child: (context){
            return FlatButton(onPressed: (){
              Navigator.push(context, MaterialPageRoute(builder: (context){
                return OnePageScreen();
              }));
            }, child: Text('To one page screen'));
          }
      ),
      NavigationDestination(
          icon: Icon(Icons.title),
          title: Text('Test 2'),
          subTitle: Text('List'),
          child: (context){
            return SingleChildScrollView(
              child: Column(
                children: List.generate(10, (index){
                  return ListTile(title: Text('Item $index'),);
                }),
              ),
            );
          }
      ),
      NavigationDestination(icon: Icon(Icons.title),
          title: Text('Test 3'),
          subTitle: Text('With actions'),
          actions: <Widget>[
            IconButton(icon: Icon(Icons.settings), onPressed: () {
              _key.currentState.callSnackBar(SnackBar(content: Text('Action!')));
            })
          ],
          child: (context){
            return Container(
              child: Center(
                child: FlatButton(child: Text('Open persisten bottom sheet') , onPressed: () {
                  Backdrop.of(context).showPersistentBottomSheet(context: context, background: Colors.greenAccent, builder: (context){
                    return Container(
                      child: Center(
                        child: RawMaterialButton(onPressed: (){
                          ControllerBottomSheet.of(context).close();
                        }, child: Text('Close'),),
                      ),
                    );
                  });
                }),
              ),
            );
          }
      )
    ];
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.green,
      ),
      home: BackdropScaffold.navigation(key: _key, titleAppBar: Text('Backdrop example'), destinations: destinations),
    );
  }
}

==> 1.0.3.tar.gz: example/example_backdrop/lib/main.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:backdrop_material_widget/backdrop_material_widget.dart';
import 'package:example_backdrop/one_page_screen.dart';

void main() => runApp(MyApp());

List<String> genList(int length) => List<String>.generate(length, (index) => 'Item $index');

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final GlobalKey<BackdropScaffoldState> _key = GlobalKey();
    final destinations = [
      NavigationDestination(
          icon: Icon(Icons.title),
          title: Text('Empty page'),
          child: (context){
            return Container(
              color: Colors.yellow,
              child: Center(
                child: FlatButton(onPressed: (){
                  Navigator.push(context, MaterialPageRoute(builder: (context){
                    return OnePageScreen();
                  }));
                }, child: Text('To one page screen')),
              ),
            );
          }
      ),
      NavigationDestination(
          icon: Icon(Icons.title),
          title: Text('Page list'),
          subTitle: Text('With infinite list length'),
          child: (context){
            return FutureBuilder<List<String>>(
              future: compute<int, List<String>>(genList, 1000),
              builder: (context, snapshot){
                if(!snapshot.hasData)
                  return Center(
                    child: CircularProgressIndicator(),
                  );
                if(snapshot.data.isEmpty)
                  return Center(
                    child: Text('List is empty'),
                  );
                return ListView.builder(
                  itemCount: snapshot.data.length,
                  itemBuilder: (context, index) => ListTile(title: Text(snapshot.data[index]),),
                );
              },
            );
          }
      ),
      NavigationDestination(icon: Icon(Icons.title),
          title: Text('Test 3'),
          subTitle: Text('Page with action'),
          actions: <Widget>[
            IconButton(icon: Icon(Icons.settings), onPressed: () {
              _key.currentState.callSnackBar(SnackBar(content: Text('Action!')));
            })
          ],
          child: (context){
            return Container(
              color: Colors.blueGrey,
              child: Center(
                child: FlatButton(child: Text('Open persisten bottom sheet') , onPressed: () {
                  Backdrop.of(context).showPersistentBottomSheet(context: context, background: Colors.greenAccent, builder: (context){
                    return Container(
                      child: Center(
                        child: RawMaterialButton(onPressed: (){
                          ControllerBottomSheet.of(context).close();
                        }, child: Text('Close'),),
                      ),
                    );
                  });
                }),
              ),
            );
          }
      )
    ];
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.green,
      ),
      home: BackdropScaffold.navigation(key: _key, titleAppBar: Text('Backdrop example'), destinations: destinations),
    );
  }
}
